;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; helper for building agenda file lists
(defun load-org-agenda-files-recursively (dir) "Find all directories in DIR."
    (unless (file-directory-p dir) (error "Not a directory `%s'" dir))
    (unless (equal (directory-files dir nil org-agenda-file-regexp t) nil)
      (add-to-list 'org-agenda-files dir)
    )
    (dolist (file (directory-files dir nil nil t))
        (unless (member file '("." ".."))
            (let ((file (concat dir file "/")))
                (when (file-directory-p file)
                    (load-org-agenda-files-recursively file)
                )
            )
        )
    )
)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; org-agenda tuning (view stuff only)
(setq org-agenda-todo-ignore-scheduled 'all)
;; Remove completed deadline tasks from the agenda view
(setq org-agenda-skip-deadline-if-done t)
;; Remove completed scheduled tasks from the agenda view
(setq org-agenda-skip-scheduled-if-done t)
;; Remove completed items from search results
(setq org-agenda-skip-timestamp-if-done t)
;; dont tend to care about tag inheritance outside of search
(setq org-agenda-use-tag-inheritance nil)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; Set some org agendas/dashboards
(setq org-agenda-sorting-strategy 
    '(
      (agenda habit-down time-up scheduled-down priority-down category-keep)
      (todo habit-up time-down scheduled-down deadline-down todo-state-down priority-down alpha-up)
      (tags priority-down category-keep)
      (search category-keep)
     )
)

(setq org-agenda-file-regexp "\\`[^.].*\\.org\\'")
(setq org-agenda-files (list 
    "~/org/_index.org"
    "~/org/_todo.org"
    "~/org/health/_health.org"
    "~/org/health/health_houdini.org"
    "~/org/health/health_mike.org"
))


(setq org-agenda-custom-commands
      '(
          ("r" "Personal"
              (
                  (agenda "" (
                      (org-agenda-overriding-header "Personal")
                  ))
                  (agenda "" (
                      (org-agenda-overriding-header "Habits")
                      (org-agenda-files (list "~/org/_habits.org"))
                  ))
                  (todo "+WIP-STYLE=\"habit\"" (
                      (org-agenda-overriding-header "WIP")
                  ))
                  (todo "+READY-STYLE=\"habit\"" (
                      (org-agenda-overriding-header "Ready")
                  ))
                  (tags-todo "+PRIORITY<\"D\"-STYLE=\"habit\"" (
                      (org-agenda-overriding-header "To Do")
                  ))
                  (tags-todo "+PRIORITY>=\"D\"-STYLE=\"habit\"-TODO=\"WIP\"-TODO=\"READY\"" (
                      (org-agenda-overriding-header "Low Priority")
                  ))
               )
          )
          ("d" "Destiny"
              (
                  (agenda "" (
                      (org-agenda-start-on-weekday 2)
                      (org-agenda-overriding-header "Destiny")
                      (org-agenda-files (list "~/org/games_destiny.org"))
                  ))
                  (todo "WIP" (
                      (org-agenda-overriding-header "WIP")
                      (org-agenda-files (list "~/org/games_destiny.org"))
                  ))
                  (todo "READY" (
                      (org-agenda-overriding-header "Ready")
                      (org-agenda-files (list "~/org/games_destiny.org"))
                  ))
                  (tags-todo "+resonance_needed>0-STYLE=\"habit\"-WIP-READY" (
                      (org-agenda-overriding-header "Weapon Shaping")
                      (org-agenda-files (list "~/org/games_destiny.org"))
                  ))
                  (tags-todo "+resonance_needed<=0+level_at_all_perks_or_higher<>\"true\"-STYLE=\"habit\"-TODO=\"WIP\"-TODO=\"READY\"" (
                      (org-agenda-overriding-header "Weapon Leveling")
                      (org-agenda-files (list "~/org/games_destiny.org"))
                  ))
                  (tags-todo "+resonance_needed<=0+level_at_all_perks_or_higher=\"true\"+masterworked<>\"true\"-STYLE=\"habit\"-TODO=\"WIP\"-TODO=\"READY\"" (
                      (org-agenda-overriding-header "Weapon Upgrades")
                      (org-agenda-files (list "~/org/games_destiny.org"))
                  ))
               )
           )
           ("o" . "Photography")
        )
)
